pub enum SisError {
SendRequestError(Error),
CreateClientError(Error),
AuthError,
ParseLoginResultError,
}Expand description
The error type for the Sis struct
Variants
SendRequestError(Error)
There was an error while sending the request to the server (It can be a network error or a server error)
CreateClientError(Error)
There was an error creating the client that will be used to send the requests
AuthError
The provided username or password is incorrect
ParseLoginResultError
There was an error while parsing the response from the server (Unexpected response)